# Big Bash View 3

### Easily create interfaces for Linux systems!

**BigBashView** is a interface for rendering bash output using QWebEngine or WebKitGtk2.
 It rendering also supports a wide variety of languages, such as Python, Ruby, Perl and PHP.

* Create powerful frontend using common known languages, such as HTML, JS and Shell!
* Demo for all functions available!
* Smooth learning curve!

### Learn more

Visit [BigLinux Blog](https://biglinux.blogspot.com/2009/07/bigbashview-em-busca-da-revolucao.html) and [BigBashView's section](https://gitlab.com/biglinux/bigbashview/blob/master/bigbashview/usr/share/bigbashview/README.md)

Check out our [legacy page on Google Code](https://code.google.com/archive/p/bigbashview/wikis/Documentation.wiki)

